==> amarok-2.6.0.tar.xz: amarok-2.6.0/tests/core-impl/playlists/types/file/TestPlaylistFileSupport.h <==
/***************************************************************************
 *   Copyright (c) 2009 Sven Krohlas <sven@getamarok.com>                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef TESTPLAYLISTFILESUPPORT_H
#define TESTPLAYLISTFILESUPPORT_H

#include <QtCore/QObject>
#include <QtCore/QString>

class TestPlaylistFileSupport : public QObject
{
Q_OBJECT

public:
    TestPlaylistFileSupport();

private slots:
    void initTestCase();
    void testGetFormat();
    void testIsPlaylist();

private:
    QString m_testPlaylistPath;
};


#endif // TESTPLAYLISTFILESUPPORT_H

==> amarok-3.3.0.tar.xz: amarok-3.3.0/tests/core-impl/playlists/types/file/TestPlaylistFileSupport.h <==
/***************************************************************************
 *   Copyright (c) 2009 Sven Krohlas <sven@asbest-online.de>               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef TESTPLAYLISTFILESUPPORT_H
#define TESTPLAYLISTFILESUPPORT_H

#include <QObject>
#include <QString>

class TestPlaylistFileSupport : public QObject
{
Q_OBJECT

public:
    TestPlaylistFileSupport();

private Q_SLOTS:
    void initTestCase();
    void testGetFormat();
    void testIsPlaylist();

private:
    QString m_testPlaylistPath;
};


#endif // TESTPLAYLISTFILESUPPORT_H
